Chapter One
==============

:Author: proycon
:Date: 2015-03-16

This is a test. The test contains *multiple sentences* in one paragraph. This one contains no newlines, unlike the next three paragraphs.

Lorem ipsum dolor sit amet, consectetur adipiscing elit. Integer nec odio.
Praesent libero. Sed cursus ante dapibus diam. Sed nisi. Nulla quis sem at nibh
elementum imperdiet. Duis sagittis ipsum. Praesent mauris. Fusce nec tellus sed
augue semper porta. Mauris massa. Vestibulum lacinia arcu eget nulla. Class
aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos
himenaeos. Curabitur sodales ligula in libero. Sed dignissim lacinia nunc. 

Curabitur tortor. Pellentesque nibh. Aenean quam. In scelerisque sem at dolor.
Maecenas mattis. Sed convallis tristique sem. Proin ut ligula vel nunc egestas
porttitor. Morbi lectus risus, iaculis vel, suscipit quis, luctus non, massa.
Fusce ac turpis quis ligula lacinia aliquet. Mauris ipsum. Nulla metus metus,
ullamcorper vel, tincidunt sed, euismod in, nibh. 

Section 1
-------------

Quisque volutpat condimentum velit. Class aptent taciti sociosqu ad litora
torquent per conubia nostra, per inceptos himenaeos. Nam nec ante. Sed lacinia,
urna non tincidunt mattis, tortor neque adipiscing diam, a cursus ipsum ante
quis turpis. Nulla facilisi. Ut fringilla. Suspendisse potenti. Nunc feugiat mi
a tellus consequat imperdiet. Vestibulum sapien. Proin quam. Etiam ultrices.
Suspendisse in justo eu magna luctus suscipit. 

Subsection 1.1: Blocks
~~~~~~~~~~~~~~~~~~~~~~~

This is a subsection, here we have some explicit Python code in the document, which will render verbatim as a
FoLiA gap, and can not contain further annotations (useless for code and other
literals anyway)::

    print("Mind the gap")

Martin Luther King once held a famous speech, it went like this and will be rendered as a Quote element:

    I have a dream that one day this nation will rise up and live out the true
    meaning of its creed: "We hold these truths to be self-evident, that all men
    are created equal."

    I have a dream that one day on the red hills of Georgia, the sons of former
    slaves and the sons of former slave owners will be able to sit down together at
    the table of brotherhood.

    I have a dream that one day even the state of Mississippi, a state sweltering
    with the heat of injustice, sweltering with the heat of oppression, will be
    transformed into an oasis of freedom and justice.

    I have a dream that my four little children will one day live in a nation where
    they will not be judged by the color of their skin but by the content of their
    character. 

Subsection 1.2: Literals
~~~~~~~~~~~~~~~~~~~~~~~~~~

In the unix shell, variables are *prepended* by a dollar sign, like: ``$var``.

Subsection 1.3: Unicode
~~~~~~~~~~~~~~~~~~~~~~~~~~

Фолия пользовается с многих языков!

Section 2: Lists
-------------------------

Let's make a grocery list, shall we?

- Milk
- Bread
- Apples
- Bananas

We can do it in an enumerated fashion as well, let's do it **again**:

1) Milk
2) Bread
3) Apples
4) Bananas

In case you forgot what bananas look like, here's a picture:

.. figure:: http://upload.wikimedia.org/wikipedia/commons/thumb/1/1c/Bananas_white_background.jpg/440px-Bananas_white_background.jpg 
   
   I'm a banana! Look at me move!

Now we know what to buy.

.. WARNING:: Don't eat bananas when they are green, wait until they are ready for consumption!

Prologue
----------

.. this is just a comment, it will not appear in the document and will just be an XML comment

The FoLiA website can be found at https://github.com/proycon/folia, also check
out the website of `Language Machines <http://cls.ru.nl/languagemachines>`_.



